@@ -6,6 +6,7 @@ from flask_restful import reqparse
 from flask_restful import marshal_with
 from rest_server.resource.models.helper import resource_fields
 from test_framework.dut.dut import Dut
+from test_framework.state import State
 from utils import log
 
 
@@ -23,6 +24,8 @@ class DutResource(Resource):
         log.INFO("REST refresh DUT")
         args = PARSER.parse_args()
         self.start_thread_refresh_dut()
+        result = {"msg": "start refresh dut", "state": State.PASS}
+        return result
 
     def start_thread_refresh_dut(self):
         thread_p = threading.Thread(target=self.refresh_dut)
