@@ -2,14 +2,15 @@
 from test_framework.database.dut_database import update_slot, check_lost_slot
 from tool.device.linux_nvme import LinuxNvme
 from test_framework.state import SlotState
+from utils.system import get_vendor_name
 
 
 class LinuxSlot(object):
 
-    def __init__(self, db_slots, agent_name):
+    def __init__(self, db_slots, agent_id):
         self.db_slots = db_slots
         self.live_slots = list()
-        self.agent_name = agent_name
+        self.agent_id = agent_id
         self.nvme = LinuxNvme()
 
     @update_slot
@@ -48,20 +49,20 @@ class LinuxSlot(object):
     def _format_results(self, results, dev):
         format_result = {
             "slot": dev["name"],
-            "vendor": results["ssd_config_dic"]["drive_pn"],
+            "vendor": get_vendor_name(results["ssd_config_dic"]["vid"]),
             "fw_version": results["test_fw_config_dic"]["fw_public_revision"],
             "commit": results["test_fw_config_dic"]["fw_private_revision"][0:6],
             "ise/sed": results["ssd_config_dic"]["security_type"],
             "sn": results["ssd_config_dic"]["drive_sn"],
-            "cap": results["ssd_config_dic"]["drive_tnvmcap"],
-            "bb": self.convert_t(results["drive_life_info_dic"]["count_grown_defects"]),
+            "cap": self.convert_t(results["ssd_config_dic"]["drive_tnvmcap"]),
+            "bb": results["drive_life_info_dic"]["count_grown_defects"],
             "max_ec": results["drive_life_info_dic"]["nand_max_erase_count"],
             "avg_ec": results["drive_life_info_dic"]["nand_avg_erase_count"],
-            "agent": self.agent_name,
+            "agent": self.agent_id,
             "status": SlotState.Idle
         }
         return format_result
 
     @staticmethod
     def convert_t(cap):
-        return float('%.2f' % (cap/1000/1000/1000/1000))
\ No newline at end of file
+        return float('%.2f' % (cap/1000/1000/1000/1000))
