@@ -47,11 +47,11 @@ class TestType(object):
         pass
 
 
-class NodeState(object):
-    Online = 1
-    Offline = 2
-    Running = 3
-    Idle = 4
+class AgentState(object):
+    Online = 0
+    Offline = 1
+    Running = 2
+    Idle = 3
     verdicts_map = {
         Online: "online",
         Offline: "offline",
@@ -60,6 +60,23 @@ class NodeState(object):
     }
 
 
+class SlotState(object):
+    Idle = 0
+    Standby = 1
+    Build = 2
+    Download = 3
+    Testing = 4
+    Lost = 5
+    verdicts_map = {
+        Idle: "Idle",
+        Standby: "Standby",
+        Build: "Build",
+        Download: "Download",
+        Testing: "Testing",
+        Lost: "Lost",
+    }
+
+
 class DownloadType(object):
 
     NVMe = 0
